from setuptools import setup

setup(name='punj_distributions1',
      version='0.1',
      description='Gaussian & Binomial distributions',
      packages=['punj_distributions1'],
      zip_safe=False)
